#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.3.0.0-7X2QafP3VNyKnVVZ0Fqnpi

key:
    hls-alternate-number-format-plugin-2.3.0.0-7X2QafP3VNyKnVVZ0Fqnpi

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  ac0a1f92b15c17c9f2c34e01e1861f26
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-alternate-number-format-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.3.0.0-7X2QafP3VNyKnVVZ0Fqnpi

depends:
    aeson-2.2.1.0-2aoKFKPwHseOu8oBERSIn base-4.18.2.1 containers-0.6.7
    extra-1.7.16-5KOCgP555FK2eQ73uTKrBZ ghc-boot-th-9.6.6
    ghcide-2.3.0.0-4WfDNWdvbs978HGuOEpRo5
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hls-graph-2.3.0.0-Dwp4mrhjHCyGH7wYWnrCby
    hls-plugin-api-2.3.0.0-21dgaLnGjvU4x9vzlj6c31
    lens-5.3.4-95zsvsVvew2LnSS9OomrvK
    lsp-2.2.0.0-FKv2O1GO4Nd9OczNPSMEVw mtl-2.3.1
    regex-tdfa-1.3.2.5-4BFfex40RxZDrdj9QrfGx5
    syb-0.7.3-3hnWhpJZuWdE2NXpC0N7hI text-2.0.2
    unordered-containers-0.2.20.1-1lWFLFb7qnGGdfGyTf5Bys

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

